//
//  TeachMateApp.swift
//  TeachMate
//
//  Created by Hongli on 2025/3/12.
//

import SwiftUI
import SwiftData
#if os(macOS)
import AppKit
#endif

// Class to manage window title across the app
class WindowTitleManager: ObservableObject {
    @Published var title: String = "TeachMate"
    
    func updateTitle(_ newTitle: String) {
        self.title = newTitle
    }
}

@main
struct TeachMateApp: App {
    @StateObject private var windowTitleManager = WindowTitleManager()
    
    var sharedModelContainer: ModelContainer = {
        let schema = Schema([
            Semester.self,
            CourseModel.self,
            ClassSession.self,
        ])
        let modelConfiguration = ModelConfiguration(schema: schema, isStoredInMemoryOnly: false)

        do {
            return try ModelContainer(for: schema, configurations: [modelConfiguration])
        } catch {
            fatalError("Could not create ModelContainer: \(error)")
        }
    }()

    var body: some Scene {
        WindowGroup {
            ContentView()
                .environmentObject(windowTitleManager)
                .onReceive(windowTitleManager.$title) { newTitle in
                    #if os(macOS)
                    NSApp.windows.first?.title = newTitle
                    #endif
                }
        }
        .modelContainer(sharedModelContainer)
        #if os(macOS)
        .windowResizability(.contentSize)
        .defaultSize(WindowSizeManager.WindowSizePreset.schedule.size)
        #endif
    }
}
