//
//  WindowSizeManager.swift
//  TeachMate
//
//  Created by Hongli on 2025/3/13.
//

import SwiftUI

#if os(macOS)
// 窗口尺寸预设
struct WindowSizeManager {
    enum WindowSizePreset {
        case calendar  // 教学历视图 - 竖长
        case schedule  // 课表视图 - 横长
        
        var size: CGSize {
            switch self {
            case .calendar:
                return CGSize(width: 500, height: 800)
            case .schedule:
                return CGSize(width: 1200, height: 680)
            }
        }
    }
}

// 扩展Scene以便于使用
extension Scene {
    func windowIdealSize(_ preset: WindowSizeManager.WindowSizePreset) -> some Scene {
        self.windowResizability(.contentSize)
            .defaultSize(preset.size)
    }
}

// 扩展View以便于在视图级别设置理想尺寸
extension View {
    func idealFrame(for preset: WindowSizeManager.WindowSizePreset) -> some View {
        self.frame(
            idealWidth: preset.size.width, 
            idealHeight: preset.size.height
        )
    }
}
#endif
